summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLinux Build Service Account <lnxbuild@localhost>2019-12-31 02:55:20 -0800
committerLinux Build Service Account <lnxbuild@localhost>2019-12-31 02:55:20 -0800
commitfab73802370bd460f3d12cf34851efee219d9ff8 (patch)
tree853b5b6b01a5ab71269b29bce0503fdcdbc2835c
parent5eb49d0d7a5b040535712518f3cf8dacbba76662 (diff)
parentb4b993ecd53146dac34bd297e1e84c63caf1a46d (diff)
Merge b4b993ecd53146dac34bd297e1e84c63caf1a46d on remote branch
Change-Id: I5dfc3a1959e56b025902fca306b1c9003b6f09eb
-rw-r--r--qdf/linux/src/qdf_mem.c7
-rw-r--r--wmi/inc/wmi_unified_param.h10
2 files changed, 12 insertions, 5 deletions
diff --git a/qdf/linux/src/qdf_mem.c b/qdf/linux/src/qdf_mem.c
index 914a130cb979..87b6bffd9b09 100644
--- a/qdf/linux/src/qdf_mem.c
+++ b/qdf/linux/src/qdf_mem.c
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2014-2018 The Linux Foundation. All rights reserved.
+ * Copyright (c) 2014-2019 The Linux Foundation. All rights reserved.
*
* Permission to use, copy, modify, and/or distribute this software for
* any purpose with or without fee is hereby granted, provided that the
@@ -1220,6 +1220,11 @@ void *qdf_mem_malloc(size_t size)
{
void *ptr;
+ if (!size || size > QDF_MEM_MAX_MALLOC) {
+ qdf_err("Cannot malloc %zu bytes", size);
+ return NULL;
+ }
+
ptr = qdf_mem_prealloc_get(size);
if (ptr)
return ptr;
diff --git a/wmi/inc/wmi_unified_param.h b/wmi/inc/wmi_unified_param.h
index 940741ac8cba..7c2759210c8b 100644
--- a/wmi/inc/wmi_unified_param.h
+++ b/wmi/inc/wmi_unified_param.h
@@ -7425,9 +7425,10 @@ struct action_wakeup_set_param {
* @WMI_ACTION_OUI_ITO_EXTENSION: for extending inactivity time of station
* @WMI_ACTION_OUI_CCKM_1X1: for TX with CCKM 1x1 only
* @WMI_ACTION_OUI_ITO_ALTERNATE: for alternate inactivity time of station
* WMI_ACTION_OUI_SWITCH_TO_11N_MODE: for switching to 11n mode connection
* WMI_ACTION_OUI_CONNECT_1x1_WITH_1_CHAIN: for 1x1 connection with 1 Chain
* @WMI_ACTION_OUI_MAXIMUM_ID: maximun number of action oui types
*/
enum wmi_action_oui_id {
WMI_ACTION_OUI_CONNECT_1X1 = 0,
@@ -7436,7 +7437,8 @@ enum wmi_action_oui_id {
WMI_ACTION_OUI_ITO_ALTERNATE = 3,
WMI_ACTION_OUI_SWITCH_TO_11N_MODE = 4,
WMI_ACTION_OUI_CONNECT_1x1_WITH_1_CHAIN = 5,
- WMI_ACTION_OUI_MAXIMUM_ID = 6,
+ WMI_ACTION_OUI_DISABLE_AGGRESSIVE_EDCA = 6,
+ WMI_ACTION_OUI_MAXIMUM_ID = 7,
};
/**
@@ -7425,9 +7425,10 @@ struct action_wakeup_set_param {
* @WMI_ACTION_OUI_CCKM_1X1: for TX with CCKM 1x1 only
* @WMI_ACTION_OUI_ITO_ALTERNATE: for alternate inactivity time of station
- * WMI_ACTION_OUI_SWITCH_TO_11N_MODE: for switching to 11n mode connection
- * WMI_ACTION_OUI_CONNECT_1x1_WITH_1_CHAIN: for 1x1 connection with 1 Chain
- * @WMI_ACTION_OUI_MAXIMUM_ID: maximun number of action oui types
+ * @WMI_ACTION_OUI_SWITCH_TO_11N_MODE: for switching to 11n mode connection
+ * @WMI_ACTION_OUI_CONNECT_1x1_WITH_1_CHAIN: for 1x1 connection with 1 Chain
+ * @WMI_ACTION_OUI_DISABLE_AGGRESSIVE_EDCA: disable aggressive EDCA with the ap
+ * @WMI_ACTION_OUI_MAXIMUM_ID: maximum number of action oui types
*/
enum wmi_action_oui_id {